From 49c48a7bbc4c0f434870d2defb6b1d9c6c4f9a21 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Milan=20P=2E=20Stani=C4=87?= <mps@arvanta.net>
Date: Sat, 15 Jan 2022 21:29:51 +0100
Subject: [PATCH] add 12x24 bold terminus fonts

---
 include/linux/font.h      |    2 +
 lib/fonts/Kconfig         |   10 +
 lib/fonts/Makefile        |    1 +
 lib/fonts/font_ter12x24.c | 1562 +++++++++++++++++++++++++++++++++++++
 lib/fonts/fonts.c         |    3 +
 5 files changed, 1578 insertions(+)
 create mode 100644 lib/fonts/font_ter12x24.c

diff --git a/include/linux/font.h b/include/linux/font.h
index abf1442ce719..e1e1c4000231 100644
--- a/include/linux/font.h
+++ b/include/linux/font.h
@@ -35,6 +35,7 @@ struct font_desc {
 #define FONT6x10_IDX	10
 #define TER16x32_IDX	11
 #define FONT6x8_IDX	12
+#define TER12x24_IDX	13
 
 extern const struct font_desc	font_vga_8x8,
 			font_vga_8x16,
@@ -48,6 +49,7 @@ extern const struct font_desc	font_vga_8x8,
 			font_mini_4x6,
 			font_6x10,
 			font_ter_16x32,
+			font_ter_12x24,
 			font_6x8;
 
 /* Find a font with a specific name */
diff --git a/lib/fonts/Kconfig b/lib/fonts/Kconfig
index c035fde66aeb..ff0f701d2ec1 100644
--- a/lib/fonts/Kconfig
+++ b/lib/fonts/Kconfig
@@ -110,6 +110,15 @@ config FONT_SUN12x22
 	  big letters (like the letters used in the SPARC PROM). If the
 	  standard font is unreadable for you, say Y, otherwise say N.
 
+config FONT_TER12x24
+	bool "Terminus 12x24 bold font (not supported by all drivers)"
+	depends on FRAMEBUFFER_CONSOLE && (!SPARC && FONTS || SPARC)
+	help
+	  Terminus Font is a clean, fixed width bitmap font, designed
+	  for long (8 and more hours per day) work with computers.
+	  This is the high resolution, large version for use with HiDPI screens.
+	  If the standard font is unreadable for you, say Y, otherwise say N.
+
 config FONT_TER16x32
 	bool "Terminus 16x32 font (not supported by all drivers)"
 	depends on FRAMEBUFFER_CONSOLE && (!SPARC && FONTS || SPARC)
@@ -138,6 +147,7 @@ config FONT_AUTOSELECT
 	depends on !FONT_SUN12x22
 	depends on !FONT_10x18
 	depends on !FONT_TER16x32
+	depends on !FONT_TER12x24
 	depends on !FONT_6x8
 	select FONT_8x16
 
diff --git a/lib/fonts/Makefile b/lib/fonts/Makefile
index e16f68492174..d26b9f64a09c 100644
--- a/lib/fonts/Makefile
+++ b/lib/fonts/Makefile
@@ -15,6 +15,7 @@ font-objs-$(CONFIG_FONT_ACORN_8x8) += font_acorn_8x8.o
 font-objs-$(CONFIG_FONT_MINI_4x6)  += font_mini_4x6.o
 font-objs-$(CONFIG_FONT_6x10)      += font_6x10.o
 font-objs-$(CONFIG_FONT_TER16x32)  += font_ter16x32.o
+font-objs-$(CONFIG_FONT_TER12x24)  += font_ter12x24.o
 font-objs-$(CONFIG_FONT_6x8)       += font_6x8.o
 
 font-objs += $(font-objs-y)
diff --git a/lib/fonts/font_ter12x24.c b/lib/fonts/font_ter12x24.c
new file mode 100644
index 000000000000..5b50e83a766c
--- /dev/null
+++ b/lib/fonts/font_ter12x24.c
@@ -0,0 +1,1562 @@
+// SPDX-License-Identifier: GPL-2.0
+#include <linux/font.h>
+#include <linux/module.h>
+
+#define FONTDATAMAX 16384
+
+static const struct font_data fontdata_ter12x24 = {
+	{ 0, 0, FONTDATAMAX, 0 }, {
+
+
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x30, 0xc0, 0x30, 0x00, 
+   0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 0x7f, 0x00, 
+   0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 
+   0x30, 0x60, 0x30, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 0 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x66, 0x60, 0x36, 0xc0, 
+   0x1f, 0x80, 0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 1 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0xf0, 
+   0x03, 0xf0, 0x0f, 0xf0, 0x3f, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0x3f, 0xf0, 0x0f, 0xf0, 0x03, 0xf0, 
+   0x00, 0xf0, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 2 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0xf0, 0x00, 
+   0xfc, 0x00, 0xff, 0x00, 0xff, 0xc0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xc0, 0xff, 0x00, 0xfc, 0x00, 
+   0xf0, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 3 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x1f, 0x80, 0x36, 0xc0, 
+   0x66, 0x60, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 4 */
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00, 
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00, 
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00, 
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00, 
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00, 
+   0xaa, 0xa0, 0x00, 0x00, 0xaa, 0xa0, 0x00, 0x00,   /* 5 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xc0, 
+   0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0xc0, 
+   0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0xc0, 
+   0x3f, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 6 */
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50, 
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50, 
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50, 
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50, 
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50, 
+   0xaa, 0xa0, 0x55, 0x50, 0xaa, 0xa0, 0x55, 0x50,   /* 7 */
+   0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x31, 0x80, 
+   0x31, 0x80, 0x31, 0x80, 0x31, 0x80, 0x1f, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 8 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x0f, 0x00, 
+   0x1f, 0x80, 0x3f, 0xc0, 0x7f, 0xe0, 0xff, 0xf0, 
+   0xff, 0xf0, 0x7f, 0xe0, 0x3f, 0xc0, 0x1f, 0x80, 
+   0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 9 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 
+   0x03, 0x00, 0x01, 0x80, 0x00, 0xc0, 0x01, 0x80, 
+   0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x30, 0x00, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 10 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 11 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xf0, 
+   0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 12 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0xf9, 0xf0, 0xf9, 0xf0, 0x00, 0x00, 
+   0x00, 0x00, 0xf9, 0xf0, 0xf9, 0xf0, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80,   /* 13 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0xff, 0xf0, 
+   0xff, 0xf0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 14 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0xc0, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x30, 0x00, 0x18, 0x00, 
+   0x0c, 0x00, 0x06, 0x00, 0x03, 0x00, 0x01, 0x80, 
+   0x00, 0xc0, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 15 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x07, 0xf0, 
+   0x07, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 16 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0xfe, 0x00, 
+   0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 17 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0xff, 0xf0, 0xff, 0xf0, 0x06, 0x00, 
+   0x06, 0x00, 0xff, 0xf0, 0xff, 0xf0, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 18 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 19 */
+   0xff, 0xf0, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 20 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0xff, 0xf0, 0xff, 0xf0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 21 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0xff, 0xf0, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 22 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0xff, 0xf0, 0xff, 0xf0,   /* 23 */
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 
+   0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0,   /* 24 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xf0, 
+   0xff, 0xf0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 25 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0xfe, 0x00, 
+   0xfe, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 26 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x07, 0xf0, 
+   0x07, 0xf0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 27 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0xff, 0xf0, 
+   0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 28 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xf0, 
+   0x07, 0xf0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 29 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 
+   0xfe, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 30 */
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00,   /* 31 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 32 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 33 */
+   0x00, 0x00, 0x00, 0x00, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 34 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 
+   0x7f, 0xe0, 0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x7f, 0xe0, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 35 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x1f, 0x80, 0x36, 0xc0, 0x66, 0x60, 
+   0x66, 0x00, 0x66, 0x00, 0x36, 0x00, 0x1f, 0x80, 
+   0x06, 0xc0, 0x06, 0x60, 0x06, 0x60, 0x66, 0x60, 
+   0x36, 0xc0, 0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 36 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x38, 0xc0, 0x6c, 0xc0, 0x6d, 0x80, 
+   0x39, 0x80, 0x03, 0x00, 0x03, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x19, 0xc0, 
+   0x1b, 0x60, 0x33, 0x60, 0x31, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 37 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x0e, 0x00, 0x1b, 0x00, 0x31, 0x80, 0x31, 0x80, 
+   0x31, 0x80, 0x1b, 0x00, 0x0e, 0x00, 0x1e, 0x60, 
+   0x33, 0x60, 0x61, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 
+   0x61, 0xc0, 0x33, 0x60, 0x1e, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 38 */
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 39 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 0x0c, 0x00, 
+   0x0c, 0x00, 0x06, 0x00, 0x03, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 40 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 
+   0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x0c, 0x00, 0x18, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 41 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0xc0, 
+   0x31, 0x80, 0x1b, 0x00, 0x0e, 0x00, 0xff, 0xe0, 
+   0x0e, 0x00, 0x1b, 0x00, 0x31, 0x80, 0x60, 0xc0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 42 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 43 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 44 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 45 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 46 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0xc0, 0x00, 0xc0, 0x01, 0x80, 
+   0x01, 0x80, 0x03, 0x00, 0x03, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x30, 0x00, 0x30, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 47 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0xe0, 0x61, 0xe0, 0x63, 0x60, 0x66, 0x60, 
+   0x6c, 0x60, 0x78, 0x60, 0x70, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 48 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0e, 0x00, 0x1e, 0x00, 0x36, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x3f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 49 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x00, 0x60, 0x00, 0xc0, 0x01, 0x80, 
+   0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x30, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 50 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0xc0, 0x0f, 0x80, 
+   0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 51 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x60, 0x00, 0xe0, 0x01, 0xe0, 0x03, 0x60, 
+   0x06, 0x60, 0x0c, 0x60, 0x18, 0x60, 0x30, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 52 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 0x00, 0xc0, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 53 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0xc0, 0x30, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 0x60, 0xc0, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 54 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x00, 0x60, 
+   0x00, 0xc0, 0x00, 0xc0, 0x01, 0x80, 0x01, 0x80, 
+   0x03, 0x00, 0x03, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 55 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 
+   0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 56 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x30, 0x60, 
+   0x1f, 0xe0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0xc0, 0x3f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 57 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 58 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 59 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0xc0, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x30, 0x00, 0x60, 0x00, 
+   0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 
+   0x03, 0x00, 0x01, 0x80, 0x00, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 60 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 61 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 
+   0x06, 0x00, 0x03, 0x00, 0x01, 0x80, 0x00, 0xc0, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x18, 0x00, 0x30, 0x00, 0x60, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 62 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x00, 0xc0, 0x01, 0x80, 0x03, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 63 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0x80, 0x60, 0xc0, 0xc0, 0x60, 0xc3, 0xe0, 
+   0xc6, 0x60, 0xcc, 0x60, 0xcc, 0x60, 0xcc, 0x60, 
+   0xcc, 0x60, 0xcc, 0x60, 0xc6, 0x60, 0xc3, 0xe0, 
+   0xc0, 0x00, 0x60, 0x00, 0x3f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 64 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 65 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x60, 0xc0, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 66 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 67 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 68 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 69 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 70 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x63, 0xe0, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 71 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 72 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 73 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x03, 0xf0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 
+   0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 
+   0x00, 0xc0, 0x00, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 
+   0x60, 0xc0, 0x31, 0x80, 0x1f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 74 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0xc0, 0x61, 0x80, 0x63, 0x00, 
+   0x66, 0x00, 0x6c, 0x00, 0x78, 0x00, 0x70, 0x00, 
+   0x78, 0x00, 0x6c, 0x00, 0x66, 0x00, 0x63, 0x00, 
+   0x61, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 75 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 76 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x80, 0x20, 0xc0, 0x60, 0xe0, 0xe0, 0xf1, 0xe0, 
+   0xdb, 0x60, 0xce, 0x60, 0xc4, 0x60, 0xc0, 0x60, 
+   0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 
+   0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 77 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x70, 0x60, 0x78, 0x60, 0x6c, 0x60, 0x66, 0x60, 
+   0x63, 0x60, 0x61, 0xe0, 0x60, 0xe0, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 78 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 79 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 80 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x66, 0x60, 0x33, 0xc0, 0x1f, 0x80, 0x00, 0xc0, 
+   0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 81 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 
+   0x78, 0x00, 0x6c, 0x00, 0x66, 0x00, 0x63, 0x00, 
+   0x61, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 82 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x30, 0x00, 0x1f, 0x80, 
+   0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 83 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 84 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 85 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x30, 0xc0, 0x30, 0xc0, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 
+   0x0f, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 86 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 
+   0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 
+   0xc4, 0x60, 0xce, 0x60, 0xdb, 0x60, 0xf1, 0xe0, 
+   0xe0, 0xe0, 0xc0, 0x60, 0x80, 0x20, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 87 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x19, 0x80, 0x30, 0xc0, 
+   0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 88 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x0f, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 89 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0xc0, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x30, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 90 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x00, 0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x18, 0x00, 0x1f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 91 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x30, 0x00, 0x30, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x03, 0x00, 0x03, 0x00, 0x01, 0x80, 
+   0x01, 0x80, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 92 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x00, 0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 
+   0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 
+   0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 0x03, 0x00, 
+   0x03, 0x00, 0x03, 0x00, 0x1f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 93 */
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x0f, 0x00, 
+   0x19, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 94 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 95 */
+   0x00, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 96 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 97 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 98 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 99 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 100 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x30, 0x60, 0x1f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 101 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x03, 0xe0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x3f, 0xc0, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 102 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xe0, 0x1f, 0xe0, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0xc0, 0x3f, 0x80, 0x00, 0x00,   /* 103 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 104 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 105 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0x00, 
+   0x03, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 
+   0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 
+   0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x30, 0xc0, 
+   0x30, 0xc0, 0x19, 0x80, 0x0f, 0x00, 0x00, 0x00,   /* 106 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 
+   0x30, 0x60, 0x30, 0xc0, 0x31, 0x80, 0x33, 0x00, 
+   0x36, 0x00, 0x3c, 0x00, 0x36, 0x00, 0x33, 0x00, 
+   0x31, 0x80, 0x30, 0xc0, 0x30, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 107 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 108 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x66, 0xc0, 0x66, 0x60, 0x66, 0x60, 
+   0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 
+   0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 109 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 110 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 111 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00,   /* 112 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00,   /* 113 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x67, 0xe0, 0x6c, 0x00, 0x78, 0x00, 0x70, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 114 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0xc0, 0x60, 0x60, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x3f, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x60, 0x60, 0x60, 0x3f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 115 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x7f, 0x80, 0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x0c, 0x00, 0x0c, 0x00, 0x07, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 116 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 117 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 
+   0x30, 0xc0, 0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 
+   0x0f, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 118 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 
+   0x66, 0x60, 0x66, 0x60, 0x3f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 119 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x19, 0x80, 
+   0x0f, 0x00, 0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 
+   0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 120 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xe0, 0x1f, 0xe0, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0xc0, 0x3f, 0x80, 0x00, 0x00,   /* 121 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x00, 0x60, 0x00, 0xc0, 0x01, 0x80, 
+   0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x30, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 122 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x03, 0x80, 0x06, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x38, 0x00, 
+   0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x0c, 0x00, 
+   0x0c, 0x00, 0x06, 0x00, 0x03, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 123 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 124 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x38, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x03, 0x80, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x0c, 0x00, 0x38, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 125 */
+   0x00, 0x00, 0x00, 0x00, 0x3c, 0x60, 0x66, 0x60, 
+   0x66, 0x60, 0x63, 0xc0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 126 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x30, 0xc0, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 127 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x0f, 0x80, 0x18, 0xc0, 0x30, 0x60, 
+   0x60, 0x00, 0x60, 0x00, 0xff, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0xff, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x30, 0x60, 0x18, 0xc0, 0x0f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 128 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 129 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 130 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x03, 0xc0, 0x06, 0x60, 0x06, 0x60, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x3f, 0xc0, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x66, 0x00, 0x66, 0x00, 0x3c, 0x00, 0x00, 0x00,   /* 131 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xc0, 
+   0x0c, 0xc0, 0x0c, 0xc0, 0x0c, 0xc0, 0x19, 0x80, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 132 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 133 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 134 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 135 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 136 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x73, 0x00, 0xdb, 0x00, 0xde, 0x00, 
+   0x76, 0x00, 0x0c, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x18, 0x00, 0x30, 0x00, 0x30, 0x00, 0x6e, 0xe0, 
+   0x7b, 0xb0, 0xdb, 0xb0, 0xce, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 137 */
+   0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x30, 0x00, 0x1f, 0x80, 
+   0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 138 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x18, 0x00, 0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 
+   0x06, 0x00, 0x03, 0x00, 0x01, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 139 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0xf0, 0x63, 0x00, 0xc3, 0x00, 0xc3, 0x00, 
+   0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 0xc3, 0xf0, 
+   0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 
+   0xc3, 0x00, 0x63, 0x00, 0x3f, 0xf0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 140 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 141 */
+   0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0xc0, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x30, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 142 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 143 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 144 */
+   0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 145 */
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 146 */
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x60, 0x0c, 0xc0, 
+   0x0c, 0xc0, 0x0c, 0xc0, 0x0c, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 147 */
+   0x00, 0x00, 0x00, 0x00, 0x19, 0x80, 0x19, 0x80, 
+   0x19, 0x80, 0x19, 0x80, 0x33, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 148 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x0f, 0x00, 0x1f, 0x80, 0x1f, 0x80, 
+   0x1f, 0x80, 0x1f, 0x80, 0x0f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 149 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 150 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xe0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 151 */
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 152 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0xfd, 0x10, 0x31, 0xb0, 0x31, 0xf0, 0x31, 0xb0, 
+   0x31, 0xb0, 0x31, 0xb0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 153 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x3f, 0xc0, 0x60, 0x60, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x3f, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x60, 0x60, 0x60, 0x3f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 154 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 
+   0x03, 0x00, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x30, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 155 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0xc0, 0x66, 0x60, 0xc6, 0x30, 0xc6, 0x30, 
+   0xc6, 0x30, 0xc7, 0xf0, 0xc6, 0x00, 0xc6, 0x00, 
+   0xc6, 0x00, 0x66, 0x30, 0x3f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 156 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 157 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x00, 0x60, 0x00, 0xc0, 0x01, 0x80, 
+   0x03, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x18, 0x00, 
+   0x30, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 158 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x0f, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 159 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 160 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 161 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x1f, 0x80, 0x36, 0xc0, 0x66, 0x60, 0x66, 0x00, 
+   0x66, 0x00, 0x66, 0x00, 0x66, 0x00, 0x66, 0x00, 
+   0x66, 0x60, 0x36, 0xc0, 0x1f, 0x80, 0x06, 0x00, 
+   0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 162 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x30, 0xc0, 0x30, 0x00, 
+   0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 0x7f, 0x00, 
+   0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 0x30, 0x00, 
+   0x30, 0x60, 0x30, 0x60, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 163 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0xc0, 0x60, 0x60, 0xc0, 
+   0x3f, 0x80, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 
+   0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x3f, 0x80, 
+   0x60, 0xc0, 0xc0, 0x60, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 164 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x3f, 0xc0, 0x06, 0x00, 0x06, 0x00, 
+   0x3f, 0xc0, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 165 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 166 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 
+   0x31, 0x80, 0x30, 0x00, 0x30, 0x00, 0x1e, 0x00, 
+   0x33, 0x00, 0x31, 0x80, 0x31, 0x80, 0x31, 0x80, 
+   0x31, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x01, 0x80, 
+   0x01, 0x80, 0x31, 0x80, 0x1f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 167 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 168 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x3f, 0x80, 0x40, 0x40, 
+   0x9f, 0x20, 0xb1, 0xa0, 0xb1, 0xa0, 0xb0, 0x20, 
+   0xb0, 0x20, 0xb1, 0xa0, 0xb1, 0xa0, 0x9f, 0x20, 
+   0x40, 0x40, 0x3f, 0x80, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 169 */
+   0x00, 0x00, 0x3f, 0x80, 0x00, 0xc0, 0x00, 0xc0, 
+   0x3f, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 
+   0x60, 0xc0, 0x3f, 0xc0, 0x00, 0x00, 0x7f, 0xc0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 170 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x60, 0x0c, 0xc0, 0x19, 0x80, 0x33, 0x00, 
+   0x66, 0x00, 0xcc, 0x00, 0x66, 0x00, 0x33, 0x00, 
+   0x19, 0x80, 0x0c, 0xc0, 0x06, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 171 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x7f, 0xe0, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 172 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xc0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 173 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x3f, 0x80, 0x40, 0x40, 
+   0xbf, 0x20, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 
+   0xbf, 0x20, 0xb6, 0x20, 0xb3, 0x20, 0xb1, 0xa0, 
+   0x40, 0x40, 0x3f, 0x80, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 174 */
+   0x00, 0x00, 0x3f, 0xc0, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 175 */
+   0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x31, 0x80, 
+   0x31, 0x80, 0x31, 0x80, 0x31, 0x80, 0x1f, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 176 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x7f, 0xe0, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 177 */
+   0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x31, 0x80, 
+   0x31, 0x80, 0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x18, 0x00, 0x3f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 178 */
+   0x00, 0x00, 0x00, 0x00, 0x1f, 0x00, 0x31, 0x80, 
+   0x01, 0x80, 0x01, 0x80, 0x0f, 0x00, 0x01, 0x80, 
+   0x01, 0x80, 0x31, 0x80, 0x1f, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 179 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 180 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0xe0, 0x61, 0xe0, 0x7f, 0x60, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00,   /* 181 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0xe0, 0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 
+   0x66, 0x60, 0x66, 0x60, 0x66, 0x60, 0x3e, 0x60, 
+   0x06, 0x60, 0x06, 0x60, 0x06, 0x60, 0x06, 0x60, 
+   0x06, 0x60, 0x06, 0x60, 0x06, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 182 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 183 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x00, 0x00,   /* 184 */
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x0e, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 185 */
+   0x00, 0x00, 0x1f, 0x00, 0x31, 0x80, 0x60, 0xc0, 
+   0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 
+   0x31, 0x80, 0x1f, 0x00, 0x00, 0x00, 0x7f, 0xc0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 186 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0xcc, 0x00, 0x66, 0x00, 0x33, 0x00, 0x19, 0x80, 
+   0x0c, 0xc0, 0x06, 0x60, 0x0c, 0xc0, 0x19, 0x80, 
+   0x33, 0x00, 0x66, 0x00, 0xcc, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 187 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 
+   0x1c, 0x00, 0x3c, 0x00, 0x0c, 0x00, 0x0c, 0x20, 
+   0x0c, 0x60, 0x0c, 0xc0, 0x01, 0x80, 0x03, 0x00, 
+   0x06, 0x60, 0x0c, 0xe0, 0x19, 0xe0, 0x33, 0x60, 
+   0x66, 0x60, 0x47, 0xe0, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 188 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 
+   0x1c, 0x00, 0x3c, 0x00, 0x0c, 0x20, 0x0c, 0x60, 
+   0x0c, 0xc0, 0x0d, 0x80, 0x03, 0x00, 0x06, 0x00, 
+   0x0c, 0x00, 0x1b, 0xc0, 0x36, 0x60, 0x66, 0x60, 
+   0x40, 0xc0, 0x01, 0x80, 0x03, 0x00, 0x07, 0xe0, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 189 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 
+   0x66, 0x00, 0x06, 0x00, 0x1c, 0x00, 0x06, 0x20, 
+   0x66, 0x60, 0x3c, 0xc0, 0x01, 0x80, 0x03, 0x00, 
+   0x06, 0x60, 0x0c, 0xe0, 0x19, 0xe0, 0x33, 0x60, 
+   0x66, 0x60, 0x47, 0xe0, 0x00, 0x60, 0x00, 0x60, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 190 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 
+   0x18, 0x00, 0x30, 0x00, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 191 */
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 192 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 193 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 194 */
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 195 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 196 */
+   0x0f, 0x00, 0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x7f, 0xe0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 197 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0xf0, 0x63, 0x00, 0xc3, 0x00, 0xc3, 0x00, 
+   0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 0xff, 0xf0, 
+   0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 0xc3, 0x00, 
+   0xc3, 0x00, 0xc3, 0x00, 0xc3, 0xf0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 198 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x00, 0x00,   /* 199 */
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 200 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 201 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 202 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x7f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 203 */
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 204 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 205 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 206 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 207 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0xfe, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 208 */
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x70, 0x60, 0x78, 0x60, 0x6c, 0x60, 0x66, 0x60, 
+   0x63, 0x60, 0x61, 0xe0, 0x60, 0xe0, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 209 */
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 210 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 211 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 212 */
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 213 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 214 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x60, 
+   0x30, 0xc0, 0x19, 0x80, 0x0f, 0x00, 0x06, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x30, 0xc0, 0x60, 0x60, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 215 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x70, 0x60, 0x60, 
+   0x60, 0xe0, 0x61, 0xe0, 0x63, 0x60, 0x66, 0x60, 
+   0x6c, 0x60, 0x78, 0x60, 0x70, 0x60, 0x60, 0x60, 
+   0xe0, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 216 */
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 217 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 218 */
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 219 */
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 220 */
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x30, 0xc0, 0x30, 0xc0, 
+   0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 0x0f, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 221 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x7f, 0x80, 
+   0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 222 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x3f, 0x00, 0x61, 0x80, 0x60, 0xc0, 0x60, 0xc0, 
+   0x60, 0xc0, 0x61, 0x80, 0x7f, 0x80, 0x60, 0xc0, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x70, 0x60, 0x68, 0xc0, 0x6f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 223 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 224 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 225 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 226 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 227 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 228 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x0f, 0x00, 0x19, 0x80, 0x19, 0x80, 0x0f, 0x00, 
+   0x3f, 0x80, 0x00, 0xc0, 0x00, 0x60, 0x00, 0x60, 
+   0x1f, 0xe0, 0x30, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 229 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x7b, 0xe0, 0x0e, 0x30, 0x06, 0x30, 0x06, 0x30, 
+   0x7e, 0x30, 0xc7, 0xf0, 0xc6, 0x00, 0xc6, 0x00, 
+   0xc6, 0x00, 0xc7, 0x30, 0x7d, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 230 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x0c, 0x00, 0x00, 0x00,   /* 231 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x30, 0x60, 0x1f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 232 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x30, 0x60, 0x1f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 233 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x30, 0x60, 0x1f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 234 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x7f, 0xe0, 0x60, 0x00, 0x60, 0x00, 
+   0x60, 0x00, 0x30, 0x60, 0x1f, 0xc0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 235 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 236 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 237 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 238 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x06, 0x00, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 239 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x36, 0x00, 0x1c, 0x00, 0x36, 0x00, 0x03, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 240 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 241 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 242 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 243 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 244 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1c, 0xc0, 0x36, 0xc0, 0x33, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 245 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x1f, 0x80, 0x30, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xc0, 0x1f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 246 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0xe0, 
+   0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06, 0x00, 
+   0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 247 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x1f, 0xa0, 0x30, 0xc0, 0x60, 0xe0, 0x61, 0xe0, 
+   0x63, 0x60, 0x66, 0x60, 0x6c, 0x60, 0x78, 0x60, 
+   0x70, 0x60, 0x30, 0xc0, 0x5f, 0x80, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 248 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x18, 0x00, 0x0c, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 249 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 250 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x06, 0x00, 0x0f, 0x00, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 251 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0x60, 0x1f, 0xe0, 0x00, 0x00, 
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* 252 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x01, 0x80, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xe0, 0x1f, 0xe0, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0xc0, 0x3f, 0x80, 0x00, 0x00,   /* 253 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 
+   0x7f, 0x80, 0x60, 0xc0, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0xc0, 0x7f, 0x80, 0x60, 0x00, 
+   0x60, 0x00, 0x60, 0x00, 0x60, 0x00, 0x00, 0x00,   /* 254 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+   0x19, 0x80, 0x19, 0x80, 0x19, 0x80, 0x00, 0x00, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 
+   0x60, 0x60, 0x30, 0xe0, 0x1f, 0xe0, 0x00, 0x60, 
+   0x00, 0x60, 0x00, 0xc0, 0x3f, 0x80, 0x00, 0x00,   /* 255 */
+} };
+
+
+const struct font_desc font_ter_12x24 = {
+	.idx	= TER12x24_IDX,
+	.name	= "TER12x24",
+	.width	= 12,
+	.height = 24,
+	.charcount = 256,
+	.data	= fontdata_ter12x24.data,
+#ifdef __sparc__
+	.pref	= 5,
+#else
+	.pref	= -1,
+#endif
+};
diff --git a/lib/fonts/fonts.c b/lib/fonts/fonts.c
index 5f4b07b56cd9..1be88be06b2b 100644
--- a/lib/fonts/fonts.c
+++ b/lib/fonts/fonts.c
@@ -54,6 +54,9 @@ static const struct font_desc *fonts[] = {
 #ifdef CONFIG_FONT_6x10
 	&font_6x10,
 #endif
+#ifdef CONFIG_FONT_TER12x24
+	&font_ter_12x24,
+#endif
 #ifdef CONFIG_FONT_TER16x32
 	&font_ter_16x32,
 #endif
-- 
2.34.1

